summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--drivers/staging/lustre/include/linux/lnet/api.h4
-rw-r--r--drivers/staging/lustre/include/linux/lnet/lib-lnet.h2
-rw-r--r--drivers/staging/lustre/include/linux/lnet/types.h6
-rw-r--r--drivers/staging/lustre/lnet/lnet/lib-me.c4
-rw-r--r--drivers/staging/lustre/lnet/lnet/lib-ptl.c2
5 files changed, 9 insertions, 9 deletions
diff --git a/drivers/staging/lustre/include/linux/lnet/api.h b/drivers/staging/lustre/include/linux/lnet/api.h
index 5537097..125d5cb 100644
--- a/drivers/staging/lustre/include/linux/lnet/api.h
+++ b/drivers/staging/lustre/include/linux/lnet/api.h
@@ -97,7 +97,7 @@ int LNetMEAttach(unsigned int portal,
__u64 match_bits_in,
__u64 ignore_bits_in,
enum lnet_unlink unlink_in,
- lnet_ins_pos_t pos_in,
+ enum lnet_ins_pos pos_in,
struct lnet_handle_me *handle_out);
int LNetMEInsert(struct lnet_handle_me current_in,
@@ -105,7 +105,7 @@ int LNetMEInsert(struct lnet_handle_me current_in,
__u64 match_bits_in,
__u64 ignore_bits_in,
enum lnet_unlink unlink_in,
- lnet_ins_pos_t position_in,
+ enum lnet_ins_pos position_in,
struct lnet_handle_me *handle_out);
int LNetMEUnlink(struct lnet_handle_me current_in);
diff --git a/drivers/staging/lustre/include/linux/lnet/lib-lnet.h b/drivers/staging/lustre/include/linux/lnet/lib-lnet.h
index e21323f..2d684a7 100644
--- a/drivers/staging/lustre/include/linux/lnet/lib-lnet.h
+++ b/drivers/staging/lustre/include/linux/lnet/lib-lnet.h
@@ -538,7 +538,7 @@ struct list_head *lnet_mt_match_head(struct lnet_match_table *mtable,
struct lnet_match_table *lnet_mt_of_attach(unsigned int index,
struct lnet_process_id id,
__u64 mbits, __u64 ignore_bits,
- lnet_ins_pos_t pos);
+ enum lnet_ins_pos pos);
int lnet_mt_match_md(struct lnet_match_table *mtable,
struct lnet_match_info *info, struct lnet_msg *msg);
diff --git a/drivers/staging/lustre/lnet/lnet/lib-me.c b/drivers/staging/lustre/lnet/lnet/lib-me.c
index a944f1f..e9b3eed 100644
--- a/drivers/staging/lustre/lnet/lnet/lib-me.c
+++ b/drivers/staging/lustre/lnet/lnet/lib-me.c
@@ -72,7 +72,7 @@ int
LNetMEAttach(unsigned int portal,
struct lnet_process_id match_id,
__u64 match_bits, __u64 ignore_bits,
- enum lnet_unlink unlink, lnet_ins_pos_t pos,
+ enum lnet_unlink unlink, enum lnet_ins_pos pos,
struct lnet_handle_me *handle)
{
struct lnet_match_table *mtable;
@@ -143,7 +143,7 @@ int
LNetMEInsert(struct lnet_handle_me current_meh,
struct lnet_process_id match_id,
__u64 match_bits, __u64 ignore_bits,
- enum lnet_unlink unlink, lnet_ins_pos_t pos,
+ enum lnet_unlink unlink, enum lnet_ins_pos pos,
struct lnet_handle_me *handle)
{
struct lnet_me *current_me;
diff --git a/drivers/staging/lustre/lnet/lnet/lib-ptl.c b/drivers/staging/lustre/lnet/lnet/lib-ptl.c
index fc67af0..63cce0c 100644
--- a/drivers/staging/lustre/lnet/lnet/lib-ptl.c
+++ b/drivers/staging/lustre/lnet/lnet/lib-ptl.c
@@ -224,7 +224,7 @@ lnet_match2mt(struct lnet_portal *ptl, struct lnet_process_id id, __u64 mbits)
struct lnet_match_table *
lnet_mt_of_attach(unsigned int index, struct lnet_process_id id,
- __u64 mbits, __u64 ignore_bits, lnet_ins_pos_t pos)
+ __u64 mbits, __u64 ignore_bits, enum lnet_ins_pos pos)
{
struct lnet_portal *ptl;
struct lnet_match_table *mtable;
OpenPOWER on IntegriCloud
diff --git a/drivers/staging/lustre/include/linux/lnet/types.h b/drivers/staging/lustre/include/linux/lnet/types.h
index 9010895..4fde723 100644
--- a/drivers/staging/lustre/include/linux/lnet/types.h
+++ b/drivers/staging/lustre/include/linux/lnet/types.h
@@ -352,20 +352,20 @@ enum lnet_unlink {
};
/**
* Values of the type lnet_ins_pos_t are used to control where a new match
* entry is inserted. The value LNET_INS_BEFORE is used to insert the new
* entry before the current entry or before the head of the list. The value
* LNET_INS_AFTER is used to insert the new entry after the current entry
* or after the last item in the list.
*/
-typedef enum {
+enum lnet_ins_pos {
/** insert ME before current position or head of the list */
LNET_INS_BEFORE,
/** insert ME after current position or tail of the list */
LNET_INS_AFTER,
/** attach ME at tail of local CPU partition ME list */
LNET_INS_LOCAL
-} lnet_ins_pos_t;
+};
/** @} lnet_me */
@@ -352,20 +352,20 @@ enum lnet_unlink {
};
/**
- * Values of the type lnet_ins_pos_t are used to control where a new match
+ * Values of the type lnet_ins_pos are used to control where a new match
* entry is inserted. The value LNET_INS_BEFORE is used to insert the new
* entry before the current entry or before the head of the list. The value